/* Itse tehty direktiivi jota voi käyttää template-driven formissa
   HTML-elementin appEqual-attribuuttina
*/
import { Directive } from '@angular/core';
import { FormGroup, NG_VALIDATORS } from '@angular/forms';
/*
 * valid on true jos lomakkeelta argumenttina tulevan
 * olion sisältämät arvot (eli tässä salasanat) ovat samoja.
 * valid on ehto. Jos valid on false, palautetaan null,
 * jos se on true, palautetaan olio {equal: true}
 */
function equalValidator({ value }: FormGroup): { [key: string]: any } | null {
  const [first, ...rest] = Object.keys(value || {});
  const valid = rest.every(v => value[v] === value[first]);
  return valid ? null : { equal: true };
}
/*
 * Tehdään yllä olevasta funktiosta direktiivi jota voi käyttää
 * lomaketemplaatissa nimellä appEqual
 */
@Directive({
  selector: '[appEqual]',
  standalone: true,
  providers: [{ provide: NG_VALIDATORS, useValue: equalValidator, multi: true }]
})
export class EqualValidatorDirective { }
