/*
Template driven form jossa on mukana validointi. Kaksi validaattoria saadaan
ulkoisista tiedostoista (equalvalidator.ts ja ssnvalidator.ts)
*/
import { Component } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { EqualValidatorDirective } from './equalvalidator';
import { SsnValidatorDirective } from './ssnvalidator';

@Component({
  selector: 'app-templateformv',
  standalone: true,
  imports: [FormsModule, EqualValidatorDirective, SsnValidatorDirective],
  styles: [`
      form {
          width: 250px;
      }
      label {
          float: left;
          width: 200px;
      }
      input {
          float: left;
          width: 200px;
      }
      button {
          float: left;
          margin-top: 10px;
      }
      span {
          float: left;
          color: red;
          width: 200px;
      }
  `],
  template: `
    <h2>Validoitu Templateform</h2><p>Template-driven form jossa mukana validointi</p>
    <p>Validointi tehdään Angularin sisäänrakennetuilla validaattoreilla ja kahdella omalla<br />
     validaattorilla (ssnvalidator, equalvalidator) jotka ovat itse tehtyjä direktiivejä.</p>
    <p>Lomakkeelta lähetetty data logataan konsoliin vasta kun data on validia</p>
  <!-- novalidate disabloi selaimen sisäänrakennetun validoinnin joka voi häiritä -->

    <form #f="ngForm" (ngSubmit)="onSubmit(f.value, f.valid!)" novalidate>
      <div>
        <label>Username:</label>
        <!-- validaattori otetaan käyttöön kentän attribuuttina, required on sisäänrakennettu -->
        <!-- #username="ngModel" -liittää username-kentän viittauksen lomakkeen tietomalliin -->
        <input #username="ngModel" type="text" name="username" ngModel required>
        <!-- punaista ilmoitusta ei näy (on hidden) jos username on kirjoitettu tai mihinkään lomakekenttään ei ole koskettu -->
        <span [hidden]="!f.form.hasError('required', 'username')||f.pristine">Username is required</span>
      </div>

      <div>
        <label>SSN(9 numbers):</label>
        <!-- appSsn-validaattori tulee itse tehdystä direktiivistä -->
        <input #ssn="ngModel" type="text" name="ssn" ngModel appSsn>
        <!-- punaista ilmoitusta ei näy (on hidden) jos ssn on kirjoitettu oikein tai ssn-kenttään ei ole koskettu -->
        <span [hidden]="!f.form.hasError('ssn', 'ssn')||ssn.pristine">SSN is invalid</span>
      </div>
      <!-- appEqual-validaattori tulee itse tehdystä direktiivistä -->
      <div ngModelGroup="passwordsGroup" appEqual>
        <div>
          <label>Password:</label>
          <!-- minlength-validaattori on sisäänrakennettu -->
          <input #password="ngModel" type="password" name="password" ngModel required minlength="5">
          <span [hidden]="!f.form.hasError('required', ['passwordsGroup', 'password'])||password.pristine">Password is required</span>
          <span [hidden]="!f.form.hasError('minlength', ['passwordsGroup', 'password'])">Password is too short</span>
        </div>

        <div>
          <label>Confirm password:</label>
          <input type="password" name="pconfirm" ngModel>
          <span [hidden]="!f.form.hasError('equal', 'passwordsGroup')">Passwords must be the same</span>
        </div>
      </div>

      <button type="submit">Submit</button>
    </form>
  `
})

export class TemplateformvComponent {

  onSubmit(formValue: any, isFormValid: boolean) {
    // data konsoliin jos menee läpi validaattoreista
    if (isFormValid) {
      console.log(formValue);
    }
  }
}
